import axios from 'axios';
import Gateways from './resources/gateways';
import Orders from './resources/orders';
import Refunds from './resources/refunds';
import Issuers from './resources/issuers';
import Environment from './typings/env';
import { BaseUrl } from './typings/endpoints';
var Keys;
(function (Keys) {
    Keys["ENVIRONMENT"] = "environment";
})(Keys || (Keys = {}));
var MultiSafepayClient = /** @class */ (function () {
    function MultiSafepayClient(apiKey, options) {
        this.existsApiKey(apiKey);
        this.setEnviorement(options);
        this.apiKey = apiKey;
        this.gateways = new Gateways(this.createClient());
        this.orders = new Orders(this.createClient());
        this.issuers = new Issuers(this.createClient());
        this.refunds = new Refunds(this.createClient());
    }
    MultiSafepayClient.prototype.existsApiKey = function (apiKey) {
        if (apiKey === '' || apiKey === undefined || typeof apiKey !== 'string') {
            throw new Error('Empty or wrong apiKey');
        }
    };
    MultiSafepayClient.prototype.createClient = function () {
        try {
            return axios.create({
                baseURL: MultiSafepayClient.baseURL,
                headers: {
                    api_key: this.apiKey,
                    'Content-Type': 'application/json; charset=UTF-8;',
                },
            });
        }
        catch (err) {
            return err;
        }
    };
    MultiSafepayClient.prototype.setEnviorement = function (options) {
        if (options !== undefined &&
            options.hasOwnProperty(Keys.ENVIRONMENT) &&
            options.environment === Environment.TEST) {
            MultiSafepayClient.baseURL = BaseUrl.TEST;
        }
        else {
            MultiSafepayClient.baseURL = BaseUrl.LIVE;
        }
    };
    return MultiSafepayClient;
}());
export default MultiSafepayClient;
//# sourceMappingURL=multisafepay.js.map