"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("axios"));
var gateways_1 = __importDefault(require("./resources/gateways"));
var orders_1 = __importDefault(require("./resources/orders"));
var refunds_1 = __importDefault(require("./resources/refunds"));
var issuers_1 = __importDefault(require("./resources/issuers"));
var env_1 = __importDefault(require("./typings/env"));
var endpoints_1 = require("./typings/endpoints");
var Keys;
(function (Keys) {
    Keys["ENVIRONMENT"] = "environment";
})(Keys || (Keys = {}));
var MultiSafepayClient = /** @class */ (function () {
    function MultiSafepayClient(apiKey, options) {
        this.existsApiKey(apiKey);
        this.setEnviorement(options);
        this.apiKey = apiKey;
        this.gateways = new gateways_1.default(this.createClient());
        this.orders = new orders_1.default(this.createClient());
        this.issuers = new issuers_1.default(this.createClient());
        this.refunds = new refunds_1.default(this.createClient());
    }
    MultiSafepayClient.prototype.existsApiKey = function (apiKey) {
        if (apiKey === '' || apiKey === undefined || typeof apiKey !== 'string') {
            throw new Error('Empty or wrong apiKey');
        }
    };
    MultiSafepayClient.prototype.createClient = function () {
        try {
            return axios_1.default.create({
                baseURL: MultiSafepayClient.baseURL,
                headers: {
                    api_key: this.apiKey,
                    'Content-Type': 'application/json; charset=UTF-8;',
                },
            });
        }
        catch (err) {
            return err;
        }
    };
    MultiSafepayClient.prototype.setEnviorement = function (options) {
        if (options !== undefined &&
            options.hasOwnProperty(Keys.ENVIRONMENT) &&
            options.environment === env_1.default.TEST) {
            MultiSafepayClient.baseURL = endpoints_1.BaseUrl.TEST;
        }
        else {
            MultiSafepayClient.baseURL = endpoints_1.BaseUrl.LIVE;
        }
    };
    return MultiSafepayClient;
}());
exports.default = MultiSafepayClient;
//# sourceMappingURL=multisafepay.js.map